<?php

/**
 * Main Banner
 *
 * @package NewsFor
 */
if (!function_exists('newsfor_main_banner')) :
    function newsfor_main_banner($newsfor_home_section, $repeat_times)
    {
        $section_post_cat_1 = esc_html(isset($newsfor_home_section->section_post_cat_1) ? $newsfor_home_section->section_post_cat_1 : '');
        $section_post_number = esc_html(isset($newsfor_home_section->section_post_number) ? $newsfor_home_section->section_post_number : 5);
        $home_section_title_video = esc_html(isset($newsfor_home_section->home_section_title_video) ? $newsfor_home_section->home_section_title_video : '');
        $banner_query_1 = new WP_Query(array('post_type' => 'post', 'posts_per_page' => $section_post_number, 'post__not_in' => get_option("sticky_posts"), 'category_name' => esc_html($section_post_cat_1)));
        if ($banner_query_1->have_posts()) :
?>
            <div id="theme-block-<?php echo esc_attr($repeat_times); ?>" class="theme-block theme-main-carousel">
                <?php if ($home_section_title_video) { ?>
                    <header class="theme-block-header">
                        <div class="theme-block-title">
                            <?php echo esc_html($home_section_title_video); ?>
                        </div>
                    </header>
                <?php } ?>

                <div class="main-carousel-container">
                    <div class="column-row">
                        <div class="column column-8 column-sm-12">
                            <div class="main-carousel-content">
                                <?php
                                $slider_pagenav = '';
                                while ($banner_query_1->have_posts()) {
                                    $banner_query_1->the_post();
                                    $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'large');
                                    $featured_image = isset($featured_image[0]) ? $featured_image[0] : '';
                                ?>
                                    <div class="slider-item">
                                        <?php
                                        add_filter('booster_extension_filter_like_ed', function () {
                                            return false;
                                        });
                                        $content = apply_filters('the_content', get_the_content());
                                        $video = false;

                                        // Only get video from the content if a playlist isn't present.
                                        if (false === strpos($content, 'wp-playlist-script')) {

                                            $video = get_media_embedded_in_content($content, array('video', 'object', 'embed', 'iframe'));
                                        }
                                        if (!empty($video)) {

                                            foreach ($video as $video_html) { ?>

                                                <div class="entry-video">
                                                    <div class="theme-video-panel video-main-wraper" data-id="video-id-<?php echo absint(get_the_ID()); ?>">
                                                        <?php echo newsfor_iframe_escape($video_html); ?>
                                                    </div>
                                                </div>

                                            <?php
                                                break;
                                            }
                                        } else { ?>
                                            <article class="theme-news-article">
                                                <div class="data-bg data-bg-big data-bg-overlay" data-background='<?php echo esc_url($featured_image); ?>'></div>
                                                <div class="article-content has-article-content-overlay article-content-overlay">

                                                    <h2 class="entry-title entry-title-xl line-clamp-2">
                                                        <a href="<?php the_permalink(); ?>" tabindex="0" rel="bookmark" title="<?php the_title_attribute(); ?>">
                                                            <?php the_title(); ?>
                                                        </a>
                                                    </h2>

                                                    <div class="entry-meta entry-meta-bottom">
                                                        <div class="entry-meta-inline">
                                                            <?php newsfor_posted_by(); ?>
                                                            <?php newsfor_post_view_count(); ?>
                                                        </div>
                                                    </div>
                                                    <div class="entry-content hidden-xs-element entry-content-muted content-muted-small">
                                                        <?php
                                                        if (has_excerpt()) {
                                                            the_excerpt();
                                                        } else {
                                                            echo '<p>';
                                                            echo esc_html(wp_trim_words(get_the_content(), 40, '...'));
                                                            echo '</p>';
                                                        } ?>
                                                    </div>
                                                </div>
                                            </article>
                                        <?php } ?>
                                    </div>
                                    <?php
                                    $slider_pagenav .= '<div class="carousel-pagination-item mb-16">';
                                    $slider_pagenav .= '<img src="' . esc_url($featured_image) . '"></img>';
                                    $slider_pagenav .= '<h4>' . esc_html(get_the_title()) . '</h4>';
                                    $slider_pagenav .= '</div>';
                                    ?>
                                <?php } ?>
                            </div>
                        </div>

                        <div class="column column-4 column-sm-12">
                            <div class="main-carousel-pagination">
                                <?php echo $slider_pagenav; ?>
                            </div>
                        </div>
                    </div>

                </div>

            </div>
<?php wp_reset_postdata();
        endif;
    }
endif;
